package build_test

import (
	"path/filepath"
	"testing"

	"git.akyoto.dev/cli/q/src/build"
	"git.akyoto.dev/cli/q/src/config"
	"git.akyoto.dev/go/assert"
)

func TestBuildDirectory(t *testing.T) {
	b := build.New("../../examples/hello")
	_, err := b.Run()
	assert.Nil(t, err)
}

func TestBuildFile(t *testing.T) {
	b := build.New("../../examples/hello/hello.q")
	_, err := b.Run()
	assert.Nil(t, err)
}

func TestExecutableFromDirectory(t *testing.T) {
	b := build.New("../../examples/hello")
	exe := filepath.Base(b.Executable())

	if config.TargetOS != config.Windows {
		assert.Equal(t, exe, "hello")
	} else {
		assert.Equal(t, exe, "hello.exe")
	}
}

func TestExecutableFromFile(t *testing.T) {
	b := build.New("../../examples/hello/hello.q")
	exe := filepath.Base(b.Executable())

	if config.TargetOS != config.Windows {
		assert.Equal(t, exe, "hello")
	} else {
		assert.Equal(t, exe, "hello.exe")
	}
}

func TestNonExisting(t *testing.T) {
	b := build.New("does-not-exist")
	_, err := b.Run()
	assert.NotNil(t, err)
}
