package config

import "runtime"

var (
	ConstantFold   bool   // Calculates the result of operations on constants at compile time.
	Dry            bool   // Skips writing the executable to disk.
	ShowAssembly   bool   // Shows assembly instructions at the end.
	ShowStatistics bool   // Shows statistics at the end.
	TargetArch     string // Target architecture.
	TargetOS       OS     // Target platform.
)

// Reset resets the configuration to its default values.
func Reset() {
	ShowAssembly = false
	ShowStatistics = false
	Dry = false
	TargetArch = runtime.GOARCH

	switch runtime.GOOS {
	case "linux":
		TargetOS = Linux
	case "darwin":
		TargetOS = Mac
	case "windows":
		TargetOS = Windows
	default:
		TargetOS = Unknown
	}

	Optimize(true)
}

// Optimize enables or disables all the optimizations at once.
func Optimize(enable bool) {
	ConstantFold = enable
}
