package core

import (
	"git.akyoto.dev/cli/q/src/ast"
	"git.akyoto.dev/cli/q/src/cpu"
	"git.akyoto.dev/cli/q/src/expression"
	"git.akyoto.dev/cli/q/src/token"
)

// Execute executes an operation on a register with a value operand.
func (f *Function) Execute(operation token.Token, register cpu.Register, value *expression.Expression) error {
	if value.IsLeaf() {
		return f.ExecuteLeaf(operation, register, value.Token)
	}

	if ast.IsFunctionCall(value) {
		_, err := f.CompileCall(value)

		if err != nil {
			return err
		}

		return f.ExecuteRegisterRegister(operation, register, f.CPU.Output[0])
	}

	tmp := f.NewRegister()
	defer f.FreeRegister(tmp)

	_, err := f.ExpressionToRegister(value, tmp)

	if err != nil {
		return err
	}

	return f.ExecuteRegisterRegister(operation, register, tmp)
}
